@@ -115,7 +115,7 @@ sub stc_build_xs {
 		'-fPIC -c -o Scintilla.o',
 		'-I.',
 		'-I' . $self->stc_get_wx_include_path,
-		'-I' . $Config{archlib} . '/CORE',
+		'-I' . $Config{archlibexp} . '/CORE',
 		Alien::wxWidgets->include_path,
 		Alien::wxWidgets->c_flags,
 		Alien::wxWidgets->defines,
